# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class IntegrationType(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        IntegrationType - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'provider': 'str',
            'images': 'list[UserImage]',
            'config_properties_schema_uri': 'str',
            'config_advanced_schema_uri': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'provider': 'provider',
            'images': 'images',
            'config_properties_schema_uri': 'configPropertiesSchemaUri',
            'config_advanced_schema_uri': 'configAdvancedSchemaUri',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._provider = None
        self._images = None
        self._config_properties_schema_uri = None
        self._config_advanced_schema_uri = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this IntegrationType.
        The ID of the integration type.

        :return: The id of this IntegrationType.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IntegrationType.
        The ID of the integration type.

        :param id: The id of this IntegrationType.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this IntegrationType.


        :return: The name of this IntegrationType.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this IntegrationType.


        :param name: The name of this IntegrationType.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this IntegrationType.
        Localized description of the integration type.

        :return: The description of this IntegrationType.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this IntegrationType.
        Localized description of the integration type.

        :param description: The description of this IntegrationType.
        :type: str
        """
        
        self._description = description

    @property
    def provider(self):
        """
        Gets the provider of this IntegrationType.
        PureCloud provider of the integration type.

        :return: The provider of this IntegrationType.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this IntegrationType.
        PureCloud provider of the integration type.

        :param provider: The provider of this IntegrationType.
        :type: str
        """
        
        self._provider = provider

    @property
    def images(self):
        """
        Gets the images of this IntegrationType.
        Collection of logos.

        :return: The images of this IntegrationType.
        :rtype: list[UserImage]
        """
        return self._images

    @images.setter
    def images(self, images):
        """
        Sets the images of this IntegrationType.
        Collection of logos.

        :param images: The images of this IntegrationType.
        :type: list[UserImage]
        """
        
        self._images = images

    @property
    def config_properties_schema_uri(self):
        """
        Gets the config_properties_schema_uri of this IntegrationType.
        URI of the schema describing the key-value properties needed to configure an integration of this type.

        :return: The config_properties_schema_uri of this IntegrationType.
        :rtype: str
        """
        return self._config_properties_schema_uri

    @config_properties_schema_uri.setter
    def config_properties_schema_uri(self, config_properties_schema_uri):
        """
        Sets the config_properties_schema_uri of this IntegrationType.
        URI of the schema describing the key-value properties needed to configure an integration of this type.

        :param config_properties_schema_uri: The config_properties_schema_uri of this IntegrationType.
        :type: str
        """
        
        self._config_properties_schema_uri = config_properties_schema_uri

    @property
    def config_advanced_schema_uri(self):
        """
        Gets the config_advanced_schema_uri of this IntegrationType.
        URI of the schema describing the advanced JSON document needed to configure an integration of this type.

        :return: The config_advanced_schema_uri of this IntegrationType.
        :rtype: str
        """
        return self._config_advanced_schema_uri

    @config_advanced_schema_uri.setter
    def config_advanced_schema_uri(self, config_advanced_schema_uri):
        """
        Sets the config_advanced_schema_uri of this IntegrationType.
        URI of the schema describing the advanced JSON document needed to configure an integration of this type.

        :param config_advanced_schema_uri: The config_advanced_schema_uri of this IntegrationType.
        :type: str
        """
        
        self._config_advanced_schema_uri = config_advanced_schema_uri

    @property
    def self_uri(self):
        """
        Gets the self_uri of this IntegrationType.
        The URI for this object

        :return: The self_uri of this IntegrationType.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this IntegrationType.
        The URI for this object

        :param self_uri: The self_uri of this IntegrationType.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ArchitectAuditMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ArchitectAuditMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'action': 'str',
            'user': 'AuditUser',
            'timestamp': 'datetime',
            'changes': 'list[Change]',
            'entity': 'AuditEntity'
        }

        self.attribute_map = {
            'action': 'action',
            'user': 'user',
            'timestamp': 'timestamp',
            'changes': 'changes',
            'entity': 'entity'
        }

        self._action = None
        self._user = None
        self._timestamp = None
        self._changes = None
        self._entity = None

    @property
    def action(self):
        """
        Gets the action of this ArchitectAuditMessage.
        The audit action

        :return: The action of this ArchitectAuditMessage.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this ArchitectAuditMessage.
        The audit action

        :param action: The action of this ArchitectAuditMessage.
        :type: str
        """
        allowed_values = ["CHECKIN", "PUBLISH", "DELETE"]
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action`, must be one of {0}"
                .format(allowed_values)
            )

        self._action = action

    @property
    def user(self):
        """
        Gets the user of this ArchitectAuditMessage.


        :return: The user of this ArchitectAuditMessage.
        :rtype: AuditUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ArchitectAuditMessage.


        :param user: The user of this ArchitectAuditMessage.
        :type: AuditUser
        """
        
        self._user = user

    @property
    def timestamp(self):
        """
        Gets the timestamp of this ArchitectAuditMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The timestamp of this ArchitectAuditMessage.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this ArchitectAuditMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param timestamp: The timestamp of this ArchitectAuditMessage.
        :type: datetime
        """
        
        self._timestamp = timestamp

    @property
    def changes(self):
        """
        Gets the changes of this ArchitectAuditMessage.


        :return: The changes of this ArchitectAuditMessage.
        :rtype: list[Change]
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """
        Sets the changes of this ArchitectAuditMessage.


        :param changes: The changes of this ArchitectAuditMessage.
        :type: list[Change]
        """
        
        self._changes = changes

    @property
    def entity(self):
        """
        Gets the entity of this ArchitectAuditMessage.


        :return: The entity of this ArchitectAuditMessage.
        :rtype: AuditEntity
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """
        Sets the entity of this ArchitectAuditMessage.


        :param entity: The entity of this ArchitectAuditMessage.
        :type: AuditEntity
        """
        
        self._entity = entity

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class IntegrationConfiguration(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        IntegrationConfiguration - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version': 'int',
            'properties_schema_uri': 'str',
            'advanced_schema_uri': 'str',
            'properties': 'object',
            'advanced': 'object',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version': 'version',
            'properties_schema_uri': 'propertiesSchemaUri',
            'advanced_schema_uri': 'advancedSchemaUri',
            'properties': 'properties',
            'advanced': 'advanced',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._version = None
        self._properties_schema_uri = None
        self._advanced_schema_uri = None
        self._properties = None
        self._advanced = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this IntegrationConfiguration.
        The globally unique identifier for the object.

        :return: The id of this IntegrationConfiguration.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IntegrationConfiguration.
        The globally unique identifier for the object.

        :param id: The id of this IntegrationConfiguration.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this IntegrationConfiguration.


        :return: The name of this IntegrationConfiguration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this IntegrationConfiguration.


        :param name: The name of this IntegrationConfiguration.
        :type: str
        """
        
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this IntegrationConfiguration.
        Version number required for updates.

        :return: The version of this IntegrationConfiguration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this IntegrationConfiguration.
        Version number required for updates.

        :param version: The version of this IntegrationConfiguration.
        :type: int
        """
        
        self._version = version

    @property
    def properties_schema_uri(self):
        """
        Gets the properties_schema_uri of this IntegrationConfiguration.
        URI for the JSON Schema describing the configuration properties in the properties field.

        :return: The properties_schema_uri of this IntegrationConfiguration.
        :rtype: str
        """
        return self._properties_schema_uri

    @properties_schema_uri.setter
    def properties_schema_uri(self, properties_schema_uri):
        """
        Sets the properties_schema_uri of this IntegrationConfiguration.
        URI for the JSON Schema describing the configuration properties in the properties field.

        :param properties_schema_uri: The properties_schema_uri of this IntegrationConfiguration.
        :type: str
        """
        
        self._properties_schema_uri = properties_schema_uri

    @property
    def advanced_schema_uri(self):
        """
        Gets the advanced_schema_uri of this IntegrationConfiguration.
        URI for the JSON Schema describing the advanced configuration

        :return: The advanced_schema_uri of this IntegrationConfiguration.
        :rtype: str
        """
        return self._advanced_schema_uri

    @advanced_schema_uri.setter
    def advanced_schema_uri(self, advanced_schema_uri):
        """
        Sets the advanced_schema_uri of this IntegrationConfiguration.
        URI for the JSON Schema describing the advanced configuration

        :param advanced_schema_uri: The advanced_schema_uri of this IntegrationConfiguration.
        :type: str
        """
        
        self._advanced_schema_uri = advanced_schema_uri

    @property
    def properties(self):
        """
        Gets the properties of this IntegrationConfiguration.
        Key-value configuration settings described by the schema in the propertiesSchemaUri field.

        :return: The properties of this IntegrationConfiguration.
        :rtype: object
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this IntegrationConfiguration.
        Key-value configuration settings described by the schema in the propertiesSchemaUri field.

        :param properties: The properties of this IntegrationConfiguration.
        :type: object
        """
        
        self._properties = properties

    @property
    def advanced(self):
        """
        Gets the advanced of this IntegrationConfiguration.
        Advanced configuration described by the schema in the advancedSchemaUri field.

        :return: The advanced of this IntegrationConfiguration.
        :rtype: object
        """
        return self._advanced

    @advanced.setter
    def advanced(self, advanced):
        """
        Sets the advanced of this IntegrationConfiguration.
        Advanced configuration described by the schema in the advancedSchemaUri field.

        :param advanced: The advanced of this IntegrationConfiguration.
        :type: object
        """
        
        self._advanced = advanced

    @property
    def self_uri(self):
        """
        Gets the self_uri of this IntegrationConfiguration.
        The URI for this object

        :return: The self_uri of this IntegrationConfiguration.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this IntegrationConfiguration.
        The URI for this object

        :param self_uri: The self_uri of this IntegrationConfiguration.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Scene(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Scene - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'scene_group': 'SceneGroup',
            'assets': 'list[Asset]',
            'thumbnail': 'Thumbnail',
            'description': 'str',
            'waypoints': 'list[Waypoint]',
            'default_orientation_y': 'float',
            'type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'scene_group': 'sceneGroup',
            'assets': 'assets',
            'thumbnail': 'thumbnail',
            'description': 'description',
            'waypoints': 'waypoints',
            'default_orientation_y': 'defaultOrientationY',
            'type': 'type',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._scene_group = None
        self._assets = None
        self._thumbnail = None
        self._description = None
        self._waypoints = None
        self._default_orientation_y = None
        self._type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Scene.
        The globally unique identifier for the object.

        :return: The id of this Scene.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Scene.
        The globally unique identifier for the object.

        :param id: The id of this Scene.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Scene.


        :return: The name of this Scene.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Scene.


        :param name: The name of this Scene.
        :type: str
        """
        
        self._name = name

    @property
    def scene_group(self):
        """
        Gets the scene_group of this Scene.


        :return: The scene_group of this Scene.
        :rtype: SceneGroup
        """
        return self._scene_group

    @scene_group.setter
    def scene_group(self, scene_group):
        """
        Sets the scene_group of this Scene.


        :param scene_group: The scene_group of this Scene.
        :type: SceneGroup
        """
        
        self._scene_group = scene_group

    @property
    def assets(self):
        """
        Gets the assets of this Scene.


        :return: The assets of this Scene.
        :rtype: list[Asset]
        """
        return self._assets

    @assets.setter
    def assets(self, assets):
        """
        Sets the assets of this Scene.


        :param assets: The assets of this Scene.
        :type: list[Asset]
        """
        
        self._assets = assets

    @property
    def thumbnail(self):
        """
        Gets the thumbnail of this Scene.


        :return: The thumbnail of this Scene.
        :rtype: Thumbnail
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """
        Sets the thumbnail of this Scene.


        :param thumbnail: The thumbnail of this Scene.
        :type: Thumbnail
        """
        
        self._thumbnail = thumbnail

    @property
    def description(self):
        """
        Gets the description of this Scene.


        :return: The description of this Scene.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Scene.


        :param description: The description of this Scene.
        :type: str
        """
        
        self._description = description

    @property
    def waypoints(self):
        """
        Gets the waypoints of this Scene.


        :return: The waypoints of this Scene.
        :rtype: list[Waypoint]
        """
        return self._waypoints

    @waypoints.setter
    def waypoints(self, waypoints):
        """
        Sets the waypoints of this Scene.


        :param waypoints: The waypoints of this Scene.
        :type: list[Waypoint]
        """
        
        self._waypoints = waypoints

    @property
    def default_orientation_y(self):
        """
        Gets the default_orientation_y of this Scene.


        :return: The default_orientation_y of this Scene.
        :rtype: float
        """
        return self._default_orientation_y

    @default_orientation_y.setter
    def default_orientation_y(self, default_orientation_y):
        """
        Sets the default_orientation_y of this Scene.


        :param default_orientation_y: The default_orientation_y of this Scene.
        :type: float
        """
        
        self._default_orientation_y = default_orientation_y

    @property
    def type(self):
        """
        Gets the type of this Scene.


        :return: The type of this Scene.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Scene.


        :param type: The type of this Scene.
        :type: str
        """
        allowed_values = ["PRIMARY", "SECONDARY"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Scene.
        The URI for this object

        :return: The self_uri of this Scene.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Scene.
        The URI for this object

        :param self_uri: The self_uri of this Scene.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class FlowBody(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowBody - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'format': 'str',
            'body': 'dict(str, object)'
        }

        self.attribute_map = {
            'format': 'format',
            'body': 'body'
        }

        self._format = None
        self._body = None

    @property
    def format(self):
        """
        Gets the format of this FlowBody.
        The 'format' indicates the particular format of the 'body' contents.  Reference the Automate documentation for format information.

        :return: The format of this FlowBody.
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """
        Sets the format of this FlowBody.
        The 'format' indicates the particular format of the 'body' contents.  Reference the Automate documentation for format information.

        :param format: The format of this FlowBody.
        :type: str
        """
        
        self._format = format

    @property
    def body(self):
        """
        Gets the body of this FlowBody.
        The flow definition body according to the syntax supported by the 'format'.  Use the /processautomation/flows/schemas endpoint to get detailed syntax information for each format.

        :return: The body of this FlowBody.
        :rtype: dict(str, object)
        """
        return self._body

    @body.setter
    def body(self, body):
        """
        Sets the body of this FlowBody.
        The flow definition body according to the syntax supported by the 'format'.  Use the /processautomation/flows/schemas endpoint to get detailed syntax information for each format.

        :param body: The body of this FlowBody.
        :type: dict(str, object)
        """
        
        self._body = body

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ComposerTemplate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ComposerTemplate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'created_date': 'datetime',
            'modified_date': 'datetime',
            'version': 'int',
            'level': 'str',
            'tags': 'list[str]',
            'data': 'dict(str, object)',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate',
            'version': 'version',
            'level': 'level',
            'tags': 'tags',
            'data': 'data',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._created_date = None
        self._modified_date = None
        self._version = None
        self._level = None
        self._tags = None
        self._data = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ComposerTemplate.
        The globally unique identifier for the object.

        :return: The id of this ComposerTemplate.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ComposerTemplate.
        The globally unique identifier for the object.

        :param id: The id of this ComposerTemplate.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ComposerTemplate.


        :return: The name of this ComposerTemplate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ComposerTemplate.


        :param name: The name of this ComposerTemplate.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ComposerTemplate.


        :return: The description of this ComposerTemplate.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ComposerTemplate.


        :param description: The description of this ComposerTemplate.
        :type: str
        """
        
        self._description = description

    @property
    def created_date(self):
        """
        Gets the created_date of this ComposerTemplate.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this ComposerTemplate.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this ComposerTemplate.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this ComposerTemplate.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this ComposerTemplate.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The modified_date of this ComposerTemplate.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this ComposerTemplate.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param modified_date: The modified_date of this ComposerTemplate.
        :type: datetime
        """
        
        self._modified_date = modified_date

    @property
    def version(self):
        """
        Gets the version of this ComposerTemplate.


        :return: The version of this ComposerTemplate.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ComposerTemplate.


        :param version: The version of this ComposerTemplate.
        :type: int
        """
        
        self._version = version

    @property
    def level(self):
        """
        Gets the level of this ComposerTemplate.


        :return: The level of this ComposerTemplate.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this ComposerTemplate.


        :param level: The level of this ComposerTemplate.
        :type: str
        """
        allowed_values = ["GLOBAL", "ORGANIZATION", "USER"]
        if level not in allowed_values:
            raise ValueError(
                "Invalid value for `level`, must be one of {0}"
                .format(allowed_values)
            )

        self._level = level

    @property
    def tags(self):
        """
        Gets the tags of this ComposerTemplate.


        :return: The tags of this ComposerTemplate.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this ComposerTemplate.


        :param tags: The tags of this ComposerTemplate.
        :type: list[str]
        """
        
        self._tags = tags

    @property
    def data(self):
        """
        Gets the data of this ComposerTemplate.


        :return: The data of this ComposerTemplate.
        :rtype: dict(str, object)
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this ComposerTemplate.


        :param data: The data of this ComposerTemplate.
        :type: dict(str, object)
        """
        
        self._data = data

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ComposerTemplate.
        The URI for this object

        :return: The self_uri of this ComposerTemplate.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ComposerTemplate.
        The URI for this object

        :param self_uri: The self_uri of this ComposerTemplate.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class PaymentMethod(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PaymentMethod - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'type': 'str',
            'provider_name': 'str',
            'token': 'str',
            'card_expiration_date': 'str',
            'card_last_four_digits': 'str',
            'card_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'type': 'type',
            'provider_name': 'providerName',
            'token': 'token',
            'card_expiration_date': 'cardExpirationDate',
            'card_last_four_digits': 'cardLastFourDigits',
            'card_type': 'cardType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._type = None
        self._provider_name = None
        self._token = None
        self._card_expiration_date = None
        self._card_last_four_digits = None
        self._card_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this PaymentMethod.
        The globally unique identifier for the object.

        :return: The id of this PaymentMethod.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PaymentMethod.
        The globally unique identifier for the object.

        :param id: The id of this PaymentMethod.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this PaymentMethod.


        :return: The name of this PaymentMethod.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PaymentMethod.


        :param name: The name of this PaymentMethod.
        :type: str
        """
        
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this PaymentMethod.


        :return: The type of this PaymentMethod.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this PaymentMethod.


        :param type: The type of this PaymentMethod.
        :type: str
        """
        allowed_values = ["CARD_TOKEN"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    @property
    def provider_name(self):
        """
        Gets the provider_name of this PaymentMethod.


        :return: The provider_name of this PaymentMethod.
        :rtype: str
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """
        Sets the provider_name of this PaymentMethod.


        :param provider_name: The provider_name of this PaymentMethod.
        :type: str
        """
        
        self._provider_name = provider_name

    @property
    def token(self):
        """
        Gets the token of this PaymentMethod.


        :return: The token of this PaymentMethod.
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """
        Sets the token of this PaymentMethod.


        :param token: The token of this PaymentMethod.
        :type: str
        """
        
        self._token = token

    @property
    def card_expiration_date(self):
        """
        Gets the card_expiration_date of this PaymentMethod.
        for payment methods of type CARD_TOKEN, the card's expiration date in the format YYYY-MM.

        :return: The card_expiration_date of this PaymentMethod.
        :rtype: str
        """
        return self._card_expiration_date

    @card_expiration_date.setter
    def card_expiration_date(self, card_expiration_date):
        """
        Sets the card_expiration_date of this PaymentMethod.
        for payment methods of type CARD_TOKEN, the card's expiration date in the format YYYY-MM.

        :param card_expiration_date: The card_expiration_date of this PaymentMethod.
        :type: str
        """
        
        self._card_expiration_date = card_expiration_date

    @property
    def card_last_four_digits(self):
        """
        Gets the card_last_four_digits of this PaymentMethod.


        :return: The card_last_four_digits of this PaymentMethod.
        :rtype: str
        """
        return self._card_last_four_digits

    @card_last_four_digits.setter
    def card_last_four_digits(self, card_last_four_digits):
        """
        Sets the card_last_four_digits of this PaymentMethod.


        :param card_last_four_digits: The card_last_four_digits of this PaymentMethod.
        :type: str
        """
        
        self._card_last_four_digits = card_last_four_digits

    @property
    def card_type(self):
        """
        Gets the card_type of this PaymentMethod.
        for payment methods of type CARD_TOKEN, the type of credit or debit card

        :return: The card_type of this PaymentMethod.
        :rtype: str
        """
        return self._card_type

    @card_type.setter
    def card_type(self, card_type):
        """
        Sets the card_type of this PaymentMethod.
        for payment methods of type CARD_TOKEN, the type of credit or debit card

        :param card_type: The card_type of this PaymentMethod.
        :type: str
        """
        allowed_values = ["Visa", "MasterCard", "Discover", "American Express"]
        if card_type not in allowed_values:
            raise ValueError(
                "Invalid value for `card_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._card_type = card_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this PaymentMethod.
        The URI for this object

        :return: The self_uri of this PaymentMethod.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this PaymentMethod.
        The URI for this object

        :param self_uri: The self_uri of this PaymentMethod.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class NumberOrder(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        NumberOrder - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'did': 'str',
            'effective_start_date': 'datetime',
            'effective_end_date': 'datetime',
            'last_updated': 'datetime',
            'start_auth_user_id': 'str',
            'end_auth_user_id': 'str',
            'status': 'str',
            'phone_number_type': 'str',
            'porting': 'bool',
            'billing_address': 'PortBillingAddress',
            'responsible_contact': 'PortContact',
            'company_name': 'str',
            'country_code': 'str',
            'envelope_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'did': 'did',
            'effective_start_date': 'effectiveStartDate',
            'effective_end_date': 'effectiveEndDate',
            'last_updated': 'lastUpdated',
            'start_auth_user_id': 'startAuthUserId',
            'end_auth_user_id': 'endAuthUserId',
            'status': 'status',
            'phone_number_type': 'phoneNumberType',
            'porting': 'porting',
            'billing_address': 'billingAddress',
            'responsible_contact': 'responsibleContact',
            'company_name': 'companyName',
            'country_code': 'countryCode',
            'envelope_id': 'envelopeId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._did = None
        self._effective_start_date = None
        self._effective_end_date = None
        self._last_updated = None
        self._start_auth_user_id = None
        self._end_auth_user_id = None
        self._status = None
        self._phone_number_type = None
        self._porting = False
        self._billing_address = None
        self._responsible_contact = None
        self._company_name = None
        self._country_code = None
        self._envelope_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this NumberOrder.
        The globally unique identifier for the object.

        :return: The id of this NumberOrder.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this NumberOrder.
        The globally unique identifier for the object.

        :param id: The id of this NumberOrder.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this NumberOrder.


        :return: The name of this NumberOrder.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this NumberOrder.


        :param name: The name of this NumberOrder.
        :type: str
        """
        
        self._name = name

    @property
    def did(self):
        """
        Gets the did of this NumberOrder.
        DID purchased

        :return: The did of this NumberOrder.
        :rtype: str
        """
        return self._did

    @did.setter
    def did(self, did):
        """
        Sets the did of this NumberOrder.
        DID purchased

        :param did: The did of this NumberOrder.
        :type: str
        """
        
        self._did = did

    @property
    def effective_start_date(self):
        """
        Gets the effective_start_date of this NumberOrder.
        Effective date of service for this order. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The effective_start_date of this NumberOrder.
        :rtype: datetime
        """
        return self._effective_start_date

    @effective_start_date.setter
    def effective_start_date(self, effective_start_date):
        """
        Sets the effective_start_date of this NumberOrder.
        Effective date of service for this order. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param effective_start_date: The effective_start_date of this NumberOrder.
        :type: datetime
        """
        
        self._effective_start_date = effective_start_date

    @property
    def effective_end_date(self):
        """
        Gets the effective_end_date of this NumberOrder.
        Effective disconnection date for this order. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The effective_end_date of this NumberOrder.
        :rtype: datetime
        """
        return self._effective_end_date

    @effective_end_date.setter
    def effective_end_date(self, effective_end_date):
        """
        Sets the effective_end_date of this NumberOrder.
        Effective disconnection date for this order. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param effective_end_date: The effective_end_date of this NumberOrder.
        :type: datetime
        """
        
        self._effective_end_date = effective_end_date

    @property
    def last_updated(self):
        """
        Gets the last_updated of this NumberOrder.
        Date of last update. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The last_updated of this NumberOrder.
        :rtype: datetime
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """
        Sets the last_updated of this NumberOrder.
        Date of last update. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param last_updated: The last_updated of this NumberOrder.
        :type: datetime
        """
        
        self._last_updated = last_updated

    @property
    def start_auth_user_id(self):
        """
        Gets the start_auth_user_id of this NumberOrder.
        UserId authorizing purchase

        :return: The start_auth_user_id of this NumberOrder.
        :rtype: str
        """
        return self._start_auth_user_id

    @start_auth_user_id.setter
    def start_auth_user_id(self, start_auth_user_id):
        """
        Sets the start_auth_user_id of this NumberOrder.
        UserId authorizing purchase

        :param start_auth_user_id: The start_auth_user_id of this NumberOrder.
        :type: str
        """
        
        self._start_auth_user_id = start_auth_user_id

    @property
    def end_auth_user_id(self):
        """
        Gets the end_auth_user_id of this NumberOrder.
        UserId authorizing disconnection

        :return: The end_auth_user_id of this NumberOrder.
        :rtype: str
        """
        return self._end_auth_user_id

    @end_auth_user_id.setter
    def end_auth_user_id(self, end_auth_user_id):
        """
        Sets the end_auth_user_id of this NumberOrder.
        UserId authorizing disconnection

        :param end_auth_user_id: The end_auth_user_id of this NumberOrder.
        :type: str
        """
        
        self._end_auth_user_id = end_auth_user_id

    @property
    def status(self):
        """
        Gets the status of this NumberOrder.
        Current status of this DID order

        :return: The status of this NumberOrder.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this NumberOrder.
        Current status of this DID order

        :param status: The status of this NumberOrder.
        :type: str
        """
        allowed_values = ["COMPLETE", "CONNECTING", "FAILED", "BACKORDERED", "PENDING", "ACTIVATING", "ACTIVATION_ERROR", "ERROR", "DISCONNECTED", "DISCONNECT_PENDING", "DEACTIVATING", "DEACTIVATION_ERROR", "DISCONNECT_FAILED", "SUBMITTED", "REJECTED", "SUPP", "PORT_PENDING", "FOC"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )

        self._status = status

    @property
    def phone_number_type(self):
        """
        Gets the phone_number_type of this NumberOrder.
        Class of DID being purchased (eg. us-domestic, toll-free, etc)

        :return: The phone_number_type of this NumberOrder.
        :rtype: str
        """
        return self._phone_number_type

    @phone_number_type.setter
    def phone_number_type(self, phone_number_type):
        """
        Sets the phone_number_type of this NumberOrder.
        Class of DID being purchased (eg. us-domestic, toll-free, etc)

        :param phone_number_type: The phone_number_type of this NumberOrder.
        :type: str
        """
        allowed_values = ["TOLL_FREE", "CN_DOMESTIC", "US_DOMESTIC", "US_TOLLFREE", "XA_TOLLFREE", "XB_TOLLFREE", "XC_TOLLFREE", "AG_DID", "AI_DID", "BB_DID", "BM_DID", "BS_DID", "CA_DID", "DM_DID", "DO_DID", "GD_DID", "JM_DID", "KN_DID", "KY_DID", "KZ_DID", "LC_DID", "MP_DID", "MS_DID", "RU_DID", "TC_DID", "TT_DID", "US_DID", "VC_DID", "VG_DID", "AF_DID", "AR_DID", "AT_DID", "AU_DID", "BE_DID", "BR_DID", "CH_DID", "CL_DID", "CN_DID", "CO_DID", "CU_DID", "DE_DID", "DK_DID", "EG_DID", "ES_DID", "FR_DID", "GB_DID", "GR_DID", "HU_DID", "ID_DID", "IN_DID", "IR_DID", "IT_DID", "JP_DID", "KR_DID", "LK_DID", "MM_DID", "MX_DID", "MY_DID", "NL_DID", "NO_DID", "NZ_DID", "PE_DID", "PH_DID", "PK_DID", "PL_DID", "RO_DID", "SE_DID", "SG_DID", "TH_DID", "TR_DID", "VE_DID", "VN_DID", "ZA_DID", "AD_DID", "AE_DID", "AL_DID", "AM_DID", "AO_DID", "AQ_DID", "AW_DID", "AZ_DID", "BA_DID", "BD_DID", "BF_DID", "BG_DID", "BH_DID", "BI_DID", "BJ_DID", "BL_DID", "BN_DID", "BO_DID", "BQ_DID", "BT_DID", "BW_DID", "BY_DID", "BZ_DID", "CD_DID", "CF_DID", "CG_DID", "CI_DID", "CK_DID", "CM_DID", "CR_DID", "CV_DID", "CY_DID", "CZ_DID", "DJ_DID", "DZ_DID", "EC_DID", "EE_DID", "EH_DID", "ER_DID", "ET_DID", "FI_DID", "FJ_DID", "FK_DID", "FM_DID", "FO_DID", "GA_DID", "GE_DID", "GF_DID", "GH_DID", "GI_DID", "GL_DID", "GM_DID", "GN_DID", "GP_DID", "GQ_DID", "GT_DID", "GW_DID", "GY_DID", "HK_DID", "HN_DID", "HR_DID", "HT_DID", "IE_DID", "IL_DID", "IO_DID", "IQ_DID", "IS_DID", "JO_DID", "KE_DID", "KG_DID", "KH_DID", "KI_DID", "KM_DID", "KP_DID", "KW_DID", "LA_DID", "LB_DID", "LI_DID", "LR_DID", "LS_DID", "LT_DID", "LU_DID", "LV_DID", "LY_DID", "MA_DID", "MC_DID", "MD_DID", "ME_DID", "MF_DID", "MG_DID", "MH_DID", "MK_DID", "ML_DID", "MN_DID", "MO_DID", "MQ_DID", "MR_DID", "MT_DID", "MU_DID", "MV_DID", "MW_DID", "MZ_DID", "NA_DID", "NC_DID", "NE_DID", "NF_DID", "NG_DID", "NI_DID", "NP_DID", "NR_DID", "NU_DID", "OM_DID", "PA_DID", "PF_DID", "PG_DID", "PM_DID", "PS_DID", "PT_DID", "PW_DID", "PY_DID", "QA_DID", "RE_DID", "RS_DID", "RW_DID", "SA_DID", "SB_DID", "SC_DID", "SD_DID", "SH_247_DID", "SH_290_DID", "SI_DID", "SK_DID", "SL_DID", "SM_DID", "SN_DID", "SO_DID", "SR_DID", "SS_DID", "ST_DID", "SV_DID", "SY_DID", "SZ_DID", "TD_DID", "TG_DID", "TJ_DID", "TK_DID", "TL_DID", "TM_DID", "TN_DID", "TO_DID", "TV_DID", "TW_DID", "TZ_DID", "UA_DID", "UG_DID", "UY_DID", "UZ_DID", "VU_DID", "WF_DID", "WS_DID", "XG_DID", "XN_DID", "XV_882_DID", "XV_883_DID", "YE_DID", "YT_DID", "ZM_DID", "ZW_DID", "SX_DID"]
        if phone_number_type not in allowed_values:
            raise ValueError(
                "Invalid value for `phone_number_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._phone_number_type = phone_number_type

    @property
    def porting(self):
        """
        Gets the porting of this NumberOrder.
        Whether or not the number was ported

        :return: The porting of this NumberOrder.
        :rtype: bool
        """
        return self._porting

    @porting.setter
    def porting(self, porting):
        """
        Sets the porting of this NumberOrder.
        Whether or not the number was ported

        :param porting: The porting of this NumberOrder.
        :type: bool
        """
        
        self._porting = porting

    @property
    def billing_address(self):
        """
        Gets the billing_address of this NumberOrder.
        Billing address used for a number port

        :return: The billing_address of this NumberOrder.
        :rtype: PortBillingAddress
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """
        Sets the billing_address of this NumberOrder.
        Billing address used for a number port

        :param billing_address: The billing_address of this NumberOrder.
        :type: PortBillingAddress
        """
        
        self._billing_address = billing_address

    @property
    def responsible_contact(self):
        """
        Gets the responsible_contact of this NumberOrder.
        Company contact for a number port

        :return: The responsible_contact of this NumberOrder.
        :rtype: PortContact
        """
        return self._responsible_contact

    @responsible_contact.setter
    def responsible_contact(self, responsible_contact):
        """
        Sets the responsible_contact of this NumberOrder.
        Company contact for a number port

        :param responsible_contact: The responsible_contact of this NumberOrder.
        :type: PortContact
        """
        
        self._responsible_contact = responsible_contact

    @property
    def company_name(self):
        """
        Gets the company_name of this NumberOrder.
        Company name for a number port

        :return: The company_name of this NumberOrder.
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """
        Sets the company_name of this NumberOrder.
        Company name for a number port

        :param company_name: The company_name of this NumberOrder.
        :type: str
        """
        
        self._company_name = company_name

    @property
    def country_code(self):
        """
        Gets the country_code of this NumberOrder.
        Country dial in codes (telephone dialing prefixes)

        :return: The country_code of this NumberOrder.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """
        Sets the country_code of this NumberOrder.
        Country dial in codes (telephone dialing prefixes)

        :param country_code: The country_code of this NumberOrder.
        :type: str
        """
        
        self._country_code = country_code

    @property
    def envelope_id(self):
        """
        Gets the envelope_id of this NumberOrder.
        Id of the terms and conditions envelope for the order.

        :return: The envelope_id of this NumberOrder.
        :rtype: str
        """
        return self._envelope_id

    @envelope_id.setter
    def envelope_id(self, envelope_id):
        """
        Sets the envelope_id of this NumberOrder.
        Id of the terms and conditions envelope for the order.

        :param envelope_id: The envelope_id of this NumberOrder.
        :type: str
        """
        
        self._envelope_id = envelope_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this NumberOrder.
        The URI for this object

        :return: The self_uri of this NumberOrder.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this NumberOrder.
        The URI for this object

        :param self_uri: The self_uri of this NumberOrder.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Discount(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Discount - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'annual_pre_pay': 'bool',
            'discount': 'str',
            'maximum': 'str',
            'minimum': 'str',
            'product_category': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'annual_pre_pay': 'annualPrePay',
            'discount': 'discount',
            'maximum': 'maximum',
            'minimum': 'minimum',
            'product_category': 'productCategory',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._annual_pre_pay = False
        self._discount = None
        self._maximum = None
        self._minimum = None
        self._product_category = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Discount.
        The globally unique identifier for the object.

        :return: The id of this Discount.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Discount.
        The globally unique identifier for the object.

        :param id: The id of this Discount.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Discount.


        :return: The name of this Discount.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Discount.


        :param name: The name of this Discount.
        :type: str
        """
        
        self._name = name

    @property
    def annual_pre_pay(self):
        """
        Gets the annual_pre_pay of this Discount.


        :return: The annual_pre_pay of this Discount.
        :rtype: bool
        """
        return self._annual_pre_pay

    @annual_pre_pay.setter
    def annual_pre_pay(self, annual_pre_pay):
        """
        Sets the annual_pre_pay of this Discount.


        :param annual_pre_pay: The annual_pre_pay of this Discount.
        :type: bool
        """
        
        self._annual_pre_pay = annual_pre_pay

    @property
    def discount(self):
        """
        Gets the discount of this Discount.


        :return: The discount of this Discount.
        :rtype: str
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """
        Sets the discount of this Discount.


        :param discount: The discount of this Discount.
        :type: str
        """
        
        self._discount = discount

    @property
    def maximum(self):
        """
        Gets the maximum of this Discount.


        :return: The maximum of this Discount.
        :rtype: str
        """
        return self._maximum

    @maximum.setter
    def maximum(self, maximum):
        """
        Sets the maximum of this Discount.


        :param maximum: The maximum of this Discount.
        :type: str
        """
        
        self._maximum = maximum

    @property
    def minimum(self):
        """
        Gets the minimum of this Discount.


        :return: The minimum of this Discount.
        :rtype: str
        """
        return self._minimum

    @minimum.setter
    def minimum(self, minimum):
        """
        Sets the minimum of this Discount.


        :param minimum: The minimum of this Discount.
        :type: str
        """
        
        self._minimum = minimum

    @property
    def product_category(self):
        """
        Gets the product_category of this Discount.


        :return: The product_category of this Discount.
        :rtype: str
        """
        return self._product_category

    @product_category.setter
    def product_category(self, product_category):
        """
        Sets the product_category of this Discount.


        :param product_category: The product_category of this Discount.
        :type: str
        """
        
        self._product_category = product_category

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Discount.
        The URI for this object

        :return: The self_uri of this Discount.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Discount.
        The URI for this object

        :param self_uri: The self_uri of this Discount.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Reservation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Reservation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'reserved_tn': 'str',
            'reservation_expires': 'datetime',
            'phone_number_type': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'reserved_tn': 'reservedTn',
            'reservation_expires': 'reservationExpires',
            'phone_number_type': 'phoneNumberType'
        }

        self._id = None
        self._reserved_tn = None
        self._reservation_expires = None
        self._phone_number_type = None

    @property
    def id(self):
        """
        Gets the id of this Reservation.


        :return: The id of this Reservation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Reservation.


        :param id: The id of this Reservation.
        :type: str
        """
        
        self._id = id

    @property
    def reserved_tn(self):
        """
        Gets the reserved_tn of this Reservation.


        :return: The reserved_tn of this Reservation.
        :rtype: str
        """
        return self._reserved_tn

    @reserved_tn.setter
    def reserved_tn(self, reserved_tn):
        """
        Sets the reserved_tn of this Reservation.


        :param reserved_tn: The reserved_tn of this Reservation.
        :type: str
        """
        
        self._reserved_tn = reserved_tn

    @property
    def reservation_expires(self):
        """
        Gets the reservation_expires of this Reservation.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The reservation_expires of this Reservation.
        :rtype: datetime
        """
        return self._reservation_expires

    @reservation_expires.setter
    def reservation_expires(self, reservation_expires):
        """
        Sets the reservation_expires of this Reservation.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param reservation_expires: The reservation_expires of this Reservation.
        :type: datetime
        """
        
        self._reservation_expires = reservation_expires

    @property
    def phone_number_type(self):
        """
        Gets the phone_number_type of this Reservation.
        The type of phone number (eg us-domestic, toll-free, etc).

        :return: The phone_number_type of this Reservation.
        :rtype: str
        """
        return self._phone_number_type

    @phone_number_type.setter
    def phone_number_type(self, phone_number_type):
        """
        Sets the phone_number_type of this Reservation.
        The type of phone number (eg us-domestic, toll-free, etc).

        :param phone_number_type: The phone_number_type of this Reservation.
        :type: str
        """
        allowed_values = ["TOLL_FREE", "CN_DOMESTIC", "US_DOMESTIC", "US_TOLLFREE", "XA_TOLLFREE", "XB_TOLLFREE", "XC_TOLLFREE", "AG_DID", "AI_DID", "BB_DID", "BM_DID", "BS_DID", "CA_DID", "DM_DID", "DO_DID", "GD_DID", "JM_DID", "KN_DID", "KY_DID", "KZ_DID", "LC_DID", "MP_DID", "MS_DID", "RU_DID", "TC_DID", "TT_DID", "US_DID", "VC_DID", "VG_DID", "AF_DID", "AR_DID", "AT_DID", "AU_DID", "BE_DID", "BR_DID", "CH_DID", "CL_DID", "CN_DID", "CO_DID", "CU_DID", "DE_DID", "DK_DID", "EG_DID", "ES_DID", "FR_DID", "GB_DID", "GR_DID", "HU_DID", "ID_DID", "IN_DID", "IR_DID", "IT_DID", "JP_DID", "KR_DID", "LK_DID", "MM_DID", "MX_DID", "MY_DID", "NL_DID", "NO_DID", "NZ_DID", "PE_DID", "PH_DID", "PK_DID", "PL_DID", "RO_DID", "SE_DID", "SG_DID", "TH_DID", "TR_DID", "VE_DID", "VN_DID", "ZA_DID", "AD_DID", "AE_DID", "AL_DID", "AM_DID", "AO_DID", "AQ_DID", "AW_DID", "AZ_DID", "BA_DID", "BD_DID", "BF_DID", "BG_DID", "BH_DID", "BI_DID", "BJ_DID", "BL_DID", "BN_DID", "BO_DID", "BQ_DID", "BT_DID", "BW_DID", "BY_DID", "BZ_DID", "CD_DID", "CF_DID", "CG_DID", "CI_DID", "CK_DID", "CM_DID", "CR_DID", "CV_DID", "CY_DID", "CZ_DID", "DJ_DID", "DZ_DID", "EC_DID", "EE_DID", "EH_DID", "ER_DID", "ET_DID", "FI_DID", "FJ_DID", "FK_DID", "FM_DID", "FO_DID", "GA_DID", "GE_DID", "GF_DID", "GH_DID", "GI_DID", "GL_DID", "GM_DID", "GN_DID", "GP_DID", "GQ_DID", "GT_DID", "GW_DID", "GY_DID", "HK_DID", "HN_DID", "HR_DID", "HT_DID", "IE_DID", "IL_DID", "IO_DID", "IQ_DID", "IS_DID", "JO_DID", "KE_DID", "KG_DID", "KH_DID", "KI_DID", "KM_DID", "KP_DID", "KW_DID", "LA_DID", "LB_DID", "LI_DID", "LR_DID", "LS_DID", "LT_DID", "LU_DID", "LV_DID", "LY_DID", "MA_DID", "MC_DID", "MD_DID", "ME_DID", "MF_DID", "MG_DID", "MH_DID", "MK_DID", "ML_DID", "MN_DID", "MO_DID", "MQ_DID", "MR_DID", "MT_DID", "MU_DID", "MV_DID", "MW_DID", "MZ_DID", "NA_DID", "NC_DID", "NE_DID", "NF_DID", "NG_DID", "NI_DID", "NP_DID", "NR_DID", "NU_DID", "OM_DID", "PA_DID", "PF_DID", "PG_DID", "PM_DID", "PS_DID", "PT_DID", "PW_DID", "PY_DID", "QA_DID", "RE_DID", "RS_DID", "RW_DID", "SA_DID", "SB_DID", "SC_DID", "SD_DID", "SH_247_DID", "SH_290_DID", "SI_DID", "SK_DID", "SL_DID", "SM_DID", "SN_DID", "SO_DID", "SR_DID", "SS_DID", "ST_DID", "SV_DID", "SY_DID", "SZ_DID", "TD_DID", "TG_DID", "TJ_DID", "TK_DID", "TL_DID", "TM_DID", "TN_DID", "TO_DID", "TV_DID", "TW_DID", "TZ_DID", "UA_DID", "UG_DID", "UY_DID", "UZ_DID", "VU_DID", "WF_DID", "WS_DID", "XG_DID", "XN_DID", "XV_882_DID", "XV_883_DID", "YE_DID", "YT_DID", "ZM_DID", "ZW_DID", "SX_DID"]
        if phone_number_type not in allowed_values:
            raise ValueError(
                "Invalid value for `phone_number_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._phone_number_type = phone_number_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class PortBillingAddress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PortBillingAddress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'street_address': 'str',
            'city_province': 'str',
            'state': 'str',
            'zip_postal': 'str',
            'country': 'str'
        }

        self.attribute_map = {
            'street_address': 'streetAddress',
            'city_province': 'cityProvince',
            'state': 'state',
            'zip_postal': 'zipPostal',
            'country': 'country'
        }

        self._street_address = None
        self._city_province = None
        self._state = None
        self._zip_postal = None
        self._country = None

    @property
    def street_address(self):
        """
        Gets the street_address of this PortBillingAddress.


        :return: The street_address of this PortBillingAddress.
        :rtype: str
        """
        return self._street_address

    @street_address.setter
    def street_address(self, street_address):
        """
        Sets the street_address of this PortBillingAddress.


        :param street_address: The street_address of this PortBillingAddress.
        :type: str
        """
        
        self._street_address = street_address

    @property
    def city_province(self):
        """
        Gets the city_province of this PortBillingAddress.


        :return: The city_province of this PortBillingAddress.
        :rtype: str
        """
        return self._city_province

    @city_province.setter
    def city_province(self, city_province):
        """
        Sets the city_province of this PortBillingAddress.


        :param city_province: The city_province of this PortBillingAddress.
        :type: str
        """
        
        self._city_province = city_province

    @property
    def state(self):
        """
        Gets the state of this PortBillingAddress.


        :return: The state of this PortBillingAddress.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this PortBillingAddress.


        :param state: The state of this PortBillingAddress.
        :type: str
        """
        
        self._state = state

    @property
    def zip_postal(self):
        """
        Gets the zip_postal of this PortBillingAddress.


        :return: The zip_postal of this PortBillingAddress.
        :rtype: str
        """
        return self._zip_postal

    @zip_postal.setter
    def zip_postal(self, zip_postal):
        """
        Sets the zip_postal of this PortBillingAddress.


        :param zip_postal: The zip_postal of this PortBillingAddress.
        :type: str
        """
        
        self._zip_postal = zip_postal

    @property
    def country(self):
        """
        Gets the country of this PortBillingAddress.


        :return: The country of this PortBillingAddress.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this PortBillingAddress.


        :param country: The country of this PortBillingAddress.
        :type: str
        """
        
        self._country = country

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class SocializeFilterRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SocializeFilterRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'filters': 'list[SocializeEntityFilter]',
            'page_size': 'int',
            'page_number': 'int',
            'sort_by': 'str',
            'sort_order': 'str'
        }

        self.attribute_map = {
            'filters': 'filters',
            'page_size': 'pageSize',
            'page_number': 'pageNumber',
            'sort_by': 'sortBy',
            'sort_order': 'sortOrder'
        }

        self._filters = None
        self._page_size = None
        self._page_number = None
        self._sort_by = None
        self._sort_order = None

    @property
    def filters(self):
        """
        Gets the filters of this SocializeFilterRequest.
        The list of filters used to narrow the return.

        :return: The filters of this SocializeFilterRequest.
        :rtype: list[SocializeEntityFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """
        Sets the filters of this SocializeFilterRequest.
        The list of filters used to narrow the return.

        :param filters: The filters of this SocializeFilterRequest.
        :type: list[SocializeEntityFilter]
        """
        
        self._filters = filters

    @property
    def page_size(self):
        """
        Gets the page_size of this SocializeFilterRequest.


        :return: The page_size of this SocializeFilterRequest.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this SocializeFilterRequest.


        :param page_size: The page_size of this SocializeFilterRequest.
        :type: int
        """
        
        self._page_size = page_size

    @property
    def page_number(self):
        """
        Gets the page_number of this SocializeFilterRequest.


        :return: The page_number of this SocializeFilterRequest.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this SocializeFilterRequest.


        :param page_number: The page_number of this SocializeFilterRequest.
        :type: int
        """
        
        self._page_number = page_number

    @property
    def sort_by(self):
        """
        Gets the sort_by of this SocializeFilterRequest.


        :return: The sort_by of this SocializeFilterRequest.
        :rtype: str
        """
        return self._sort_by

    @sort_by.setter
    def sort_by(self, sort_by):
        """
        Sets the sort_by of this SocializeFilterRequest.


        :param sort_by: The sort_by of this SocializeFilterRequest.
        :type: str
        """
        
        self._sort_by = sort_by

    @property
    def sort_order(self):
        """
        Gets the sort_order of this SocializeFilterRequest.


        :return: The sort_order of this SocializeFilterRequest.
        :rtype: str
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """
        Sets the sort_order of this SocializeFilterRequest.


        :param sort_order: The sort_order of this SocializeFilterRequest.
        :type: str
        """
        allowed_values = ["ascending", "descending"]
        if sort_order not in allowed_values:
            raise ValueError(
                "Invalid value for `sort_order`, must be one of {0}"
                .format(allowed_values)
            )

        self._sort_order = sort_order

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class AssociatedDocument(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AssociatedDocument - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'document': 'Document',
            'document_association_type': 'str'
        }

        self.attribute_map = {
            'document': 'document',
            'document_association_type': 'documentAssociationType'
        }

        self._document = None
        self._document_association_type = None

    @property
    def document(self):
        """
        Gets the document of this AssociatedDocument.
        the document associated with the workitem

        :return: The document of this AssociatedDocument.
        :rtype: Document
        """
        return self._document

    @document.setter
    def document(self, document):
        """
        Sets the document of this AssociatedDocument.
        the document associated with the workitem

        :param document: The document of this AssociatedDocument.
        :type: Document
        """
        
        self._document = document

    @property
    def document_association_type(self):
        """
        Gets the document_association_type of this AssociatedDocument.
        the document association type

        :return: The document_association_type of this AssociatedDocument.
        :rtype: str
        """
        return self._document_association_type

    @document_association_type.setter
    def document_association_type(self, document_association_type):
        """
        Sets the document_association_type of this AssociatedDocument.
        the document association type

        :param document_association_type: The document_association_type of this AssociatedDocument.
        :type: str
        """
        allowed_values = ["UNKNOWN", "MAIN", "SECONDARY"]
        if document_association_type not in allowed_values:
            raise ValueError(
                "Invalid value for `document_association_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._document_association_type = document_association_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

